@@ -35,7 +35,7 @@ setMethod(f=".composeFilename",
 
   if (!is.null(metaData(x)$fullName)) {
     if (length(metaData(x)$fullName) > 1) {
-      filename <- paste(metaData(x)$fullName, collapse="_", sep="")
+      filename <- paste0(metaData(x)$fullName, collapse="_")
     } else {
       filename <- metaData(x)$fullName
     }
